% Matlab script to run the example problem.
%
% v.2, 10/26/08, Paul Spudich and Jon B. Fletcher
%
% This script runs an example of use of the Matlab-language function 
% strainz17.m, which is described in Spudich, P., and Fletcher, J., 
% "Software for inference of dynamic ground strains and rotations and their
% errors from short baseline array observations of ground motions," for
% publication as a Short Note in Bulletin of the Seismological Society of
% America, 2009. 
%
% IMPORTANT WARNING:
%   The goal of this example is to show the novice Matlab user how to read
% data from simple ascii input files, place those data into the structure
% that is the input to strainz17.m, extract the results from the strainz17
% output structure, plot those results, and save the output to '.mat' and
% ascii output files.  This is not intended to be general purpose input
% and output software.  Only a subset of the useful strainz17 output is
% plotted and saved.  Output files have the barest format, and the output
% time scale is completely artificial. 
%
%
% HOW TO RUN THIS SCRIPT:
%
% 1) Set your working (current) directory to be the directory containing 
% test data files stn1.txt, stn2.txt, ..., stn14.txt.
%
% 2) Either 
%   2a) place files make_example_in_structure.m, plot_strainz_output1.m,
%   and strainz17.m in your current directory, or
%   2b) place files make_example_in_structure.m, plot_strainz_output1.m,
%   and strainz17.m in your path
%
% 3) Type RUN_THE_EXAMPLE at the Matlab '>>' prompt. 
%
% 
% Three output files will be generated: 
%   1)  A plot of strain and rotation time series is saved in a pdf file 
%           named plot_save_strainz_output1.pdf
%   2)  Numerical results are saved in a file named
%           plot_save_strainz_output1.mat
%   3)  An ascii file 'ascii_output.txt', in which row/record i contains: 
%           Column 1: t(i), an artificial example time assigned to row i
%           Column 2: maximum shear strain at time t(i)
%           Column 3: dilatation at time t(i)
%           Column 4: rotation (rad) about the x1 axis at time t(i)
%           Column 5: rotation (rad) about the x2 axis at time t(i)
%           Column 6: rotation (rad) about the x3 axis at time t(i)
%           Column 7: mistfit ratio at time t(i)
%
%
% DISCLAIMER: 
%
% Although this program has been used by the USGS, no warranty,
% expressed or implied, is made by the USGS or the United States Government
% or any authors as to the accuracy and functioning of the program and
% related program material nor shall the fact of distribution constitute
% any such warranty, and no responsibility is assumed by the USGS in
% connection therewith.
%
% COPYRIGHT INFO
% This m-file is a U.S. Government work and is not subject to copyright. It
% may be freely distributed. 
%
% ---------------- begin the active part of the code -------------------

% create strainz_in, the input structure for strainz17
strainz_in = make_example_in_structure;

% run the strain and rotation analysis
strainz_out = strainz17(strainz_in); 

% plot and save the strainz17 output rotations and strains
plot_save_strainz_output1(strainz_out)

% ---------------- end of script ----------------------------------------